@@ -7,10 +7,13 @@ use std::fmt::Debug;
 use std::ops::{Deref, DerefMut};
 use thiserror::Error;
 
-use cosmwasm_std::testing::{MockApi, MockStorage};
+use cosmwasm_std::testing::{MockApi, MockQuerier, MockStorage};
+use cosmwasm_std::OwnedDeps;
+use std::marker::PhantomData;
+
 use cosmwasm_std::{
     from_slice, to_binary, Addr, Api, Binary, BlockInfo, Coin, CustomQuery, Empty, Order, Querier,
-    StdError, StdResult, Storage, Timestamp,
+    QuerierResult, StdError, StdResult, Storage, Timestamp,
 };
 use cw_multi_test::{
     App, AppResponse, BankKeeper, BankSudo, BasicAppBuilder, CosmosRouter, Executor, Module,
@@ -43,6 +46,17 @@ const ADMIN_PRIVILEGES: &[Privilege] = &[
     Privilege::ConsensusParamChanger,
 ];
 
+pub type TgradeDeps = OwnedDeps<MockStorage, MockApi, MockQuerier, TgradeQuery>;
+
+pub fn mock_deps_tgrade() -> TgradeDeps {
+    OwnedDeps {
+        storage: MockStorage::default(),
+        api: MockApi::default(),
+        querier: MockQuerier::default(),
+        custom_query_type: PhantomData,
+    }
+}
+
 impl TgradeModule {
     /// Intended for init_modules to set someone who can grant privileges or call arbitrary
     /// TgradeMsg externally
@@ -246,6 +260,22 @@ impl Module for TgradeModule {
                 };
                 router.sudo(api, storage, block, mint.into())
             }
+            TgradeMsg::Delegate {
+                funds: _funds,
+                staker: _staker,
+            } => {
+                self.require_privilege(storage, &sender, Privilege::Delegator)?;
+                // FIXME? We don't do anything here
+                Ok(AppResponse::default())
+            }
+            TgradeMsg::Undelegate {
+                funds: _funds,
+                recipient: _recipient,
+            } => {
+                self.require_privilege(storage, &sender, Privilege::Delegator)?;
+                // FIXME? We don't do anything here
+                Ok(AppResponse::default())
+            }
         }
     }
 
@@ -323,6 +353,12 @@ impl DerefMut for TgradeApp {
     }
 }
 
+impl Querier for TgradeApp {
+    fn raw_query(&self, bin_request: &[u8]) -> QuerierResult {
+        self.0.raw_query(bin_request)
+    }
+}
+
 impl TgradeApp {
     pub fn new(owner: &str) -> Self {
         let owner = Addr::unchecked(owner);
@@ -522,4 +558,6 @@ mod tests {
             .unwrap();
         assert_eq!(end, mintable);
     }
+
+    // TODO: Delegate / Undelegate tests
 }
